SystemOrganization addCategory: #'Glamour-Seaside-Tests'!

TestCase subclass: #SGLTextModelTest
	instanceVariableNames: 'presentation model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLTextModelTest methodsFor: 'setup' stamp: 'AndreiChis 2/20/2011 23:40'!
setUp
	super setUp.

	presentation := GLMTextPresentation new.
	model := SGLTextModel for: presentation! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 22:04'!
testAnnouncerslInitialization
	|count1 count2 count3|
	count1 := 0. 
	count2 := 0.
	count3 := 0.
	model announcer on: SGLTextPresenterTextChanged do: [ :ann | count1 := count1 +1].
	model announcer on: SGLTextPresenterSelectedTextChanged do: [ :ann | count2 := count2 +1].
	model announcer on: SGLTextPresenterSelectionIntervalChanged do: [ :ann | count3 := count3 +1].
	model anounceTextChangedTo: 'text'.
	self assert: count1 = 1.
	self assert: count2 = 0.
	self assert: count3 = 0.
	model anounceSelectedTextChangedTo: 'text'.
	self assert: count1 = 1.
	self assert: count2 = 1.
	self assert: count3 = 0.
	model anounceSelectionIntervalChangedTo: (1 to: 4).
	self assert: count1 = 1.
	self assert: count2 = 1.
	self assert: count3 = 1.
	self assert: model text = nil.
	self assert: model selectionInterval = nil.
	self assert: model selectedText = nil! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 23:21'!
testIntervalForSelectionWithSelectionInterval
	model selectionInterval: (2 to: 21).
	self assert: (model intervalForSelection: nil) =  (2 to: 21).
	self assert: (model intervalForSelection: 'text') =  (2 to: 21).
	model text: 'a test text'.
	self assert: (model intervalForSelection: 'test t') = (3 to: 8).
	self assert: (model intervalForSelection: 'not found') = nil.
	! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 23:10'!
testIntervalForSelectionWithoutSelectionInterval
	self assert: (model intervalForSelection: nil) = nil.
	self assert: (model intervalForSelection: 'text') = nil.
	model text: 'a test text'.
	self assert: (model intervalForSelection: '') = nil.
	self assert: (model intervalForSelection: 'test t') = (3 to: 8).
	self assert: (model intervalForSelection: 'a test text') =  (1 to: 11).
	self assert: (model intervalForSelection: 't') =  (3 to: 3).
	self assert: (model intervalForSelection: 'not found') = nil.
	! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 22:04'!
testModelInitialization
	self assert: model glamourPresentation == presentation.
	self assert: model text = nil.
	self assert: model selectedText = nil.
	self assert: model selectionInterval = nil.
	self assert: model announcer notNil.
! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 22:04'!
testSelectedTextChanged
	|count selectedText|
	count := 0.
	model announcer on: SGLTextPresenterSelectedTextChanged do: [ :ann | 
		count := count + 1.
		selectedText := ann selectedText ].
	model selectedText: 'a text'.
	model selectedText: 'a text'.
	model selectedText: 'a text'.
	self assert: count = 1.
	self assert: selectedText  = 'a text'.
	self assert: model selectedText = 'a text'.
	self assert: model glamourPresentation selectedText = 'a text'.
	self assert: model text = nil.
	self assert: model selectionInterval = nil.
	model selectedText: nil.
	self assert: count = 2.
	self assert: selectedText  = nil.
	self assert: model selectedText = nil.
	self assert: model glamourPresentation selectedText = ''.
	! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 23:09'!
testSelectionForIntervalWithSelectedText
	model selectedText: 'selected'.
	self assert: (model selectionForInterval: nil) = 'selected'.
	self assert: (model selectionForInterval: (1 to: 100)) = 'selected'.
	model text: 'a test text'.
	self assert: (model selectionForInterval: (1 to: 11)) =  'a test text'.
	! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 23:04'!
testSelectionForIntervalWithoutSelectedText
	self assert: (model selectionForInterval: nil) = nil.
	self assert: (model selectionForInterval: (1 to: 100)) = nil.
	model text: 'a test text'.
	self assert: (model selectionForInterval: (1 to: 11)) =  'a test text'.
	self assert: (model selectionForInterval: (6 to: 1)) =  'a test'.
	self assert: (model selectionForInterval: (-2311 to: 21211)) =  'a test text'.
	self assert: (model selectionForInterval: (20 to: 100)) = nil.
	self assert: (model selectionForInterval: (-10 to: 0)) = nil.
	! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/2/2010 02:10'!
testSelectionIntervalAndSelectedTextChanged
	|count1 count2 selectionInterval selectedText|
	count1 := 0.
	count2 := 0.
	model announcer on: SGLTextPresenterSelectionIntervalChanged do: [ :ann | 
		count1 := count1 + 1.
		selectionInterval := ann selectionInterval ].
	model announcer on: SGLTextPresenterSelectedTextChanged do: [ :ann | 
		count2 := count2 + 1.
		selectedText := ann selectedText ].
	model selectionInterval: (1 to: 100) withSelectedText: 'some text'.
	model selectionInterval: (1 to: 100).
	model selectionInterval: (1 to: 100).
	self assert: count1 = 1.
	self assert: count2 = 1.
	self assert: selectionInterval  = (1 to: 100).
	self assert: selectedText = 'some text'.
	self assert: model selectionInterval = (1 to: 100).
	self assert: model selectedText = 'some text'.
	self assert: model glamourPresentation selectionInterval = (1 to: 100).
	self assert: model glamourPresentation selectedText = 'some text'.
	self assert: model text = nil.
	model selectionInterval: nil withSelectedText: nil.
	self assert: count1 = 2.
	self assert: count2 = 2.
	self assert: selectionInterval  = nil.
	self assert: selectedText = nil.
	self assert: model selectionInterval = nil.
	self assert: model selectedText = nil.
	self assert: model glamourPresentation selectionInterval = nil.
	self assert: model glamourPresentation selectedText = ''
	! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 22:05'!
testSelectionIntervalChanged
	|count selectionInterval|
	count := 0.
	model announcer on: SGLTextPresenterSelectionIntervalChanged do: [ :ann | 
		count := count + 1.
		selectionInterval := ann selectionInterval ].
	model selectionInterval: (1 to: 100).
	model selectionInterval: (1 to: 100).
	model selectionInterval: (1 to: 100).
	self assert: count = 1.
	self assert: selectionInterval  = (1 to: 100).
	self assert: model selectionInterval = (1 to: 100).
	self assert: model glamourPresentation selectionInterval = (1 to: 100).
	self assert: model selectedText = nil.
	self assert: model text = nil.
	model selectionInterval: nil.
	self assert: count = 2.
	self assert: selectionInterval  = nil.
	self assert: model selectionInterval = nil.
	self assert: model glamourPresentation selectionInterval = nil.
	! !

!SGLTextModelTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 22:05'!
testTextChanged
	|count text|
	count := 0.
	model announcer on: SGLTextPresenterTextChanged do: [ :ann | 
		count := count + 1.
		text := ann text ].
	model text: 'a text'.
	model text: 'a text'.
	model text: 'a text'.
	self assert: count = 1.
	self assert: text  = 'a text'.
	self assert: model text = 'a text'.
	self assert: model glamourPresentation text = 'a text'.
	self assert: model selectedText = nil.
	self assert: model selectionInterval = nil.
	model text: nil.
	self assert: count = 2.
	self assert: text  = nil.
	self assert: model text = nil.
	self assert: model glamourPresentation text = nil.
	! !

TestCase subclass: #SGLTreeModelTest
	instanceVariableNames: 'presentation model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLTreeModelTest methodsFor: 'setup' stamp: 'AndreiChis 10/28/2010 23:20'!
setUp
	super setUp.

	presentation := GLMTreePresentation new.
	model := SGLTreeModel for: presentation! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/28/2010 23:27'!
testAmountToFilterByWithShowOnly
	presentation showOnly: 20.
	self assert: model amountToFilterBy == 20.
	model amountToFilterBy: 10.
	self assert: model amountToFilterBy == 10.! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/28/2010 23:29'!
testAmountToFilterByWithStepSize
	presentation showOnly: 20.
	model stepSize: 14.
	self assert: model amountToFilterBy == 14! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/29/2010 00:01'!
testAnnouncerslInitialization
	| count selection |
	count := 0. 
	selection := MorphTreeMorphSingleSelection new selectedNodePath: nil.
	model announcer on: GLMTreeMorphSelectionChanged do: [ :ann | count := count +1].
	model selection: selection.
	model selection: selection.
	self assert: count = 1.
	model selection: (MorphTreeMorphSingleSelection new selectedNodePath: nil).
	self assert: count ==2! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/28/2010 23:33'!
testModelInitialization
	self assert: model glamourPresentation == presentation.
	self assert: model shouldAllExpand == false.
	self assert: model shouldRootsExpand == false.
	self assert: model amountToFilterBy == 0.
	self assert: model stepSize == 0.
	self assert: model announcer notNil.! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/29/2010 22:56'!
testRootsWithFilterByAmount
	|roots entities|
	presentation entity: (1 to: 100).
	presentation showOnly: 20.
	roots := model roots.
	self assert: roots size == 20.
	self assert: model allRoots size == 100.
	entities := OrderedCollection new.
	roots do: [:each| entities add: each item].
	self assert: entities = (1 to: 20) asOrderedCollection.
	entities := OrderedCollection new.
	model allRoots do: [:each| entities add: each item].
	self assert: entities = (1 to: 100) asOrderedCollection! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/29/2010 22:40'!
testRootsWithoutFilterByAmount
	|roots entities|
	presentation entity: (1 to: 100).
	roots := model roots.
	self assert: roots size == 100.
	self assert: model allRoots size == 100.
	entities := OrderedCollection new.
	roots do: [:each| entities add: each item].
	self assert: entities = (1 to: 100) asOrderedCollection.
	entities := OrderedCollection new.
	model allRoots do: [:each| entities add: each item].
	self assert: entities = (1 to: 100) asOrderedCollection  ! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/28/2010 23:34'!
testShouldFilterByAmountWithShowOnly
	presentation showOnly: 2.
	self assert: model shouldFilterByAmount == true.! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/28/2010 23:34'!
testShouldFilterByAmountWithStepSize
	model stepSize: 2.
	self assert: model shouldFilterByAmount == true.! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/29/2010 23:09'!
testSimpleSelection
	| count selection selectionPath |
	count := 0.
	presentation entity: (1 to: 10).
	presentation children: [:item :x :level | 
				level > 2 ifTrue: [#()] ifFalse: [ (item*10+1) to: (item*10 + 9) ] ].
	model announcer on: GLMTreeMorphSelectionChanged do: [ :ann | 
		count := count +1.
		selection := ann selectionValue.
		selectionPath := ann selectionPathValue ].
	model explicitSelection: 342.
	model explicitSelection: 342.
	self assert: count = 1.
	self assert: selection = 342.
	self assert: (selectionPath = (OrderedCollection with: 3 with:  34 with:  342)).! !

!SGLTreeModelTest methodsFor: 'testing' stamp: 'AndreiChis 10/28/2010 23:23'!
testStepSizeWithShowOnly
	presentation showOnly: 20.
	self assert: model stepSize == 20.
	model stepSize: 10.
	self assert: model stepSize == 10.! !

WtSeleniumWebTesterTestResource subclass: #SGLSeleniumWebTesterTestResource
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLSeleniumWebTesterTestResource methodsFor: 'running' stamp: 'AndreiChis 2/21/2011 23:53'!
buildWebTester 
	^ WtSeleniumWebTester new
		appRoot: self class defaultAppRoot;
		browserType: '*firefox'.! !

!WtWebTester methodsFor: '*Glamour-Seaside-Tests' stamp: 'AndreiChis 2/22/2011 22:24'!
getEval: aScript
	self subclassResponsibility! !

!WtElement methodsFor: '*Glamour-Seaside-Tests' stamp: 'AndreiChis 2/22/2011 21:41'!
fireEvent: anEvent
	self subclassResponsibility! !

!WtSeleniumElement methodsFor: '*Glamour-Seaside-Tests' stamp: 'AndreiChis 2/22/2011 21:42'!
fireEvent: anEvent
	seleniumWebTester processCommand: 'fireEvent' withParams: (Array with: self locator location with: anEvent).
	^ seleniumWebTester! !

!WtSeleniumWebTester methodsFor: '*Glamour-Seaside-Tests' stamp: 'AndreiChis 2/22/2011 22:26'!
getEval: aScript
	self processCommand: 'getEval' withParams: (Array with: aScript).! !

SGLComponent subclass: #SGLPresenterWrapper
	instanceVariableNames: 'renderable presenter renderer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLPresenterWrapper methodsFor: 'accessing' stamp: 'AndreiChis 9/2/2010 18:32'!
browser
	^ self renderableObject! !

!SGLPresenterWrapper methodsFor: 'initialization' stamp: 'AndreiChis 9/2/2010 19:23'!
initializeFor: aRenderable
	renderable := aRenderable.
	renderer :=  SGLRenderer new.
	presenter := SGLTextPresenter for: self browser from: renderer! !

!SGLPresenterWrapper methodsFor: 'initialization' stamp: 'AndreiChis 9/6/2010 02:31'!
initializeFor: aRenderable with: rendererClass
	renderable := aRenderable.
	renderer :=  SGLRenderer new.
	presenter := rendererClass perform: #for:from: with: self browser with: renderer! !

!SGLPresenterWrapper methodsFor: 'accessing' stamp: 'AndreiChis 9/2/2010 18:11'!
model
! !

!SGLPresenterWrapper methodsFor: 'accessing' stamp: 'AndreiChis 9/2/2010 18:49'!
presenter
	^ presenter! !

!SGLPresenterWrapper methodsFor: 'rendering' stamp: 'AndreiChis 9/2/2010 18:50'!
renderContentOn: html
	self session addBrowser: self browser.
	renderer html: html.
	html render: presenter
	! !

!SGLPresenterWrapper methodsFor: 'accessing' stamp: 'AndreiChis 9/2/2010 18:32'!
renderableObject
	^ renderable! !

!SGLPresenterWrapper methodsFor: 'accessing' stamp: 'AndreiChis 9/2/2010 18:32'!
renderableObject: anObject
	renderable := anObject! !

SGLComponent subclass: #SGLSimpleFinderTestComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLSimpleFinderTestComponent methodsFor: 'accessing' stamp: 'AndreiChis 2/21/2011 00:05'!
browser
	| finder |
	finder := GLMFinder new.
	finder show: [ :a |
		a list 
			display: [:x | 1 to: x] ].
		
	^finder.! !

!SGLSimpleFinderTestComponent methodsFor: 'accessing' stamp: 'AndreiChis 2/21/2011 00:05'!
model
	^ 100! !

WtSeleniumCase subclass: #SGLComponentTest
	instanceVariableNames: 'componentUnderTest'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLComponentTest classSide methodsFor: 'accessing' stamp: 'AndreiChis 2/20/2011 23:13'!
component
	^ self subclassResponsibility! !

!SGLComponentTest classSide methodsFor: 'accessing' stamp: 'AndreiChis 2/20/2011 23:14'!
componentPath
	^'glamour/componentundertesting/'! !

!SGLComponentTest classSide methodsFor: 'accessing' stamp: 'AndreiChis 2/20/2011 22:21'!
defaultAppRoot
	^GRPlatform current defaultSeasideHostAndPort, '/'! !

!SGLComponentTest classSide methodsFor: 'accessing' stamp: 'AndreiChis 2/21/2011 23:52'!
webTesterTestRessourceClass
	^ WtSeleniumWebTesterTestResource.! !

!SGLComponentTest methodsFor: 'accessing' stamp: 'AndreiChis 2/20/2011 23:15'!
componentUrl
	^self class defaultAppRoot , self class componentPath.! !

!SGLComponentTest methodsFor: 'actions' stamp: 'AndreiChis 2/22/2011 22:40'!
pause
	self pause: 5000  ! !

!SGLComponentTest methodsFor: 'actions' stamp: 'AndreiChis 2/22/2011 22:36'!
pause: waitTimeInMillis
	self getEval: 'var date = new Date(); var curDate = null;  while (curDate = new Date() - date < ', waitTimeInMillis asString, '){} '.! !

!SGLComponentTest methodsFor: 'setup' stamp: 'AndreiChis 2/22/2011 22:40'!
setUp
	super setUp.	
	componentUnderTest := self class component.
	componentUnderTest  class registerAsApplication: self class componentPath.

	self openUrl: self componentUrl.
	self pause. "Wait for javascript to finish executing"! !

!SGLComponentTest methodsFor: 'setup' stamp: 'AndreiChis 2/21/2011 00:38'!
tearDown
	componentUnderTest 
		ifNotNil: [WAAdmin defaultDispatcher unregister: componentUnderTest].! !

!SGLComponentTest methodsFor: 'accessing' stamp: 'AndreiChis 2/22/2011 22:36'!
timeToWaitInMillis
	^ 10000! !

SGLComponentTest subclass: #SGLSimpleFinderComponentTest
	instanceVariableNames: 'finderSelector paneSelector treePresentationSelector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLSimpleFinderComponentTest classSide methodsFor: 'accessing' stamp: 'AndreiChis 2/20/2011 23:19'!
component 
	^ SGLSimpleFinderTestComponent new.! !

!SGLSimpleFinderComponentTest methodsFor: 'accessing' stamp: 'AndreiChis 2/22/2011 22:51'!
fullPaneSelector
	^ '//', finderSelector , '/', paneSelector! !

!SGLSimpleFinderComponentTest methodsFor: 'setup' stamp: 'AndreiChis 2/22/2011 23:19'!
setUp
	super setUp. 
	
	finderSelector := 'body/div[contains(@class, "sgl-finder")]'.
	paneSelector := 'div[contains(@class, "sgl-finder-pane")]'.
	treePresentationSelector := 'div[contains(@class, "sgl-tree-presentation")]'.! !

!SGLSimpleFinderComponentTest methodsFor: 'testing' stamp: 'AndreiChis 2/22/2011 23:19'!
testAddOnePane
	| listElement newPane treePresentation |
	
	listElement := self elementByXPath: '//ul[contains(@class, "sgl-tree-root")]/*[20]/*'.
	listElement fireEvent: 'click'.
	self pause.
	
	"The new pane should be present"
	newPane := self elementByXPath: self fullPaneSelector, '[2]'.  
	self should: newPane isPresent.
	
	"The new pane should contain a tree presentation"
	treePresentation := self elementByXPath: self fullPaneSelector, '[2]', '/', treePresentationSelector.  
	self should: treePresentation isPresent
	! !

!SGLSimpleFinderComponentTest methodsFor: 'testing' stamp: 'AndreiChis 2/22/2011 22:50'!
testFinderIsPresent
	| finder |
	
	finder := self divByXPath: '//', finderSelector.	
	self should: finder isPresent! !

!SGLSimpleFinderComponentTest methodsFor: 'testing' stamp: 'AndreiChis 2/22/2011 22:49'!
testOneFinderPaneIsPresent
	| firstPane secondPane |
	
	firstPane := self divByXPath: self fullPaneSelector, '[1]'.
	self should: firstPane isPresent.
	
	secondPane := self divByXPath: self fullPaneSelector, '[2]'.	
	self shouldnt: secondPane isPresent.! !

!SGLSimpleFinderComponentTest methodsFor: 'testing' stamp: 'AndreiChis 2/22/2011 23:19'!
testPaneContentIsPresent
	| paneContent |
	
	paneContent := self divByXPath: self fullPaneSelector, '/', treePresentationSelector.
	self should: paneContent isPresent.
! !

!WtSeleniumCase methodsFor: '*Glamour-Seaside-Tests' stamp: 'AndreiChis 2/22/2011 22:26'!
getEval: aScript
	self webTester getEval: aScript  ! !

STTestCase subclass: #SGLPresenterTest
	instanceVariableNames: 'presentation presenter app previousDeprecationWarning'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

SGLPresenterTest subclass: #SGLAccordionCompositePresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLAccordionCompositePresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:20'!
buildPresentation
	| aPresentation |
	aPresentation := GLMCompositePresentation new.
	aPresentation accordionArrangement.
	^ aPresentation! !

!SGLAccordionCompositePresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:18'!
presenterClass
	^ SGLAccordionCompositePresenter! !

!SGLAccordionCompositePresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 23:24'!
testInitialization
	self establishSession.
	presenter presentation = presentation! !

SGLPresenterTest subclass: #SGLAccumulatorPresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLAccumulatorPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:20'!
buildPresentation
	^ GLMAccumulator new! !

!SGLAccumulatorPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 02:25'!
presenterClass
	^ SGLAccumulatorPresenter! !

!SGLAccumulatorPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 02:19'!
testInitialization
	self establishSession.
	presenter browser = presentation! !

SGLPresenterTest subclass: #SGLFinderPresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLFinderPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/7/2010 00:19'!
buildPresentation
	^ GLMFinder new! !

!SGLFinderPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/7/2010 00:19'!
presenterClass
	^ SGLFinderPresenter! !

!SGLFinderPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/7/2010 00:19'!
testInitialization
	self establishSession.
	presenter browser = presentation! !

SGLPresenterTest subclass: #SGLMondrianPresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLMondrianPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:59'!
buildPresentation
	^ GLMMondrianPresentation new! !

!SGLMondrianPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:59'!
presenterClass
	^ SGLMondrianPresenter! !

!SGLMondrianPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/7/2010 00:09'!
testInitialization
	presentation painting: [:view :number |
		view nodes: (1 to: 10) ].
	self establishSession.
	presenter presentation = presentation! !

!SGLPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:19'!
buildPresentation
	self subclassResponsibility! !

!SGLPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 02:25'!
presenterClass
	self subclassResponsibility! !

!SGLPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/26/2010 22:02'!
setUp
	super setUp.
	previousDeprecationWarning := Deprecation raiseWarning.
	Deprecation raiseWarning: false.
	
	presentation := self buildPresentation.
	app := self newApplicationWithRootClass: SGLPresenterWrapper initializeWith: [ : wrapper |
		wrapper initializeFor: presentation with: self presenterClass.
		presenter := wrapper presenter].
	SGLComponent applyPreferencesOn: app.! !

!SGLPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/26/2010 22:03'!
tearDown
	Deprecation raiseWarning: previousDeprecationWarning! !

SGLPresenterTest subclass: #SGLStackedVerticallyCompositePresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLStackedVerticallyCompositePresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:29'!
buildPresentation
	| aPresentation |
	aPresentation := GLMCompositePresentation new.
	aPresentation stackedVerticallyArrangement.
	^ aPresentation! !

!SGLStackedVerticallyCompositePresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:29'!
presenterClass
	^ SGLStackedVerticallyCompositePresenter! !

!SGLStackedVerticallyCompositePresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 23:29'!
testInitialization
	self establishSession.
	presenter presentation = presentation! !

SGLPresenterTest subclass: #SGLTabbedCompositePresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLTabbedCompositePresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:52'!
buildPresentation
	| aPresentation |
	aPresentation := GLMCompositePresentation new.
	aPresentation tabbedArrangement.
	^ aPresentation! !

!SGLTabbedCompositePresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:51'!
presenterClass
	^ SGLTabbedCompositePresenter! !

!SGLTabbedCompositePresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 23:53'!
testInitialization
	self establishSession.
	presenter presentation = presentation! !

SGLPresenterTest subclass: #SGLTabulatorPresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLTabulatorPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:56'!
buildPresentation
	^ GLMTabulator new! !

!SGLTabulatorPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:56'!
presenterClass
	^ SGLTabulatorPresenter! !

!SGLTabulatorPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 23:58'!
testInitialization
	presentation row: #row.
	self establishSession.
	presenter browser = presentation! !

SGLPresenterTest subclass: #SGLTextPresenterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Glamour-Seaside-Tests'!

!SGLTextPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 23:21'!
buildPresentation
	^ GLMTextPresentation new! !

!SGLTextPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 00:18'!
expectedFailures
	^ #(testTextWithSelectedTextAnnouncements testTextWithSelectionIntervalAnnouncements)! !

!SGLTextPresenterTest methodsFor: 'setup' stamp: 'AndreiChis 9/6/2010 02:33'!
presenterClass
	^ SGLTextPresenter! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 02:17'!
testModelInitialization
	self establishSession.
	self assert: presenter model notNil.
	self assert: presenter model glamourPresentation = presentation! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 20:16'!
testSelectedTextPortAnnouncement
	self establishSession.
	self assert: presenter model selectedText isNil.
	presentation selectedText: 'Some text'.

	self assert: presenter model selectedText = 'Some text'.
	self assert: presenter model text isNil.
	self assert: presenter model selectionInterval isNil! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 00:12'!
testSelectedTextPortInitialization
	presentation selectedText: 'test'.
	self establishSession.
	
	self assert: presentation text = nil.
	self assert: presentation selectedText = 'test'.
	self assert: presentation selectionInterval = nil.
	
	self assert: presenter model text = nil.
	self assert: presenter model selectedText = 'test'.
	self assert: presenter model selectionInterval = nil! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 20:16'!
testSelectionIntervalPortAnnouncement
	self establishSession.
	self assert: presenter model selectionInterval isNil.
	presentation selectionInterval: (-12 to: 20).

	self assert: presenter model selectionInterval = (-12 to: 20).
	self assert: presenter model text isNil.
	self assert: presenter model selectedText isNil! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 00:15'!
testSelectionIntervalPortInitialization
	presentation selectionInterval: (2 to: 10000).
	self establishSession.
	
	self assert: presentation text = nil.
	self assert: presentation selectedText = ''.
	self assert: presentation selectionInterval = (2 to: 10000).
	
	self assert: presenter model text = nil.
	self assert: presenter model selectedText = nil.
	self assert: presenter model selectionInterval = (2 to: 10000)! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 00:17'!
testSelectionPortsInitialization
	presentation selectedText: 'a selection'.
	presentation selectionInterval: (20 to: 200).
	self establishSession.
	
	self assert: presentation text = nil.
	self assert: presentation selectedText = 'a selection'.
	self assert: presentation selectionInterval = (20 to: 200).
	
	self assert: presenter model text = nil.
	self assert: presenter model selectedText = 'a selection'.
	self assert: presenter model selectionInterval = (20 to: 200)! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 20:16'!
testTextPortAnnouncement
	self establishSession.
	self assert: presenter model text isNil.
	presentation text: 'Some text'.

	self assert: presenter model text = 'Some text'.
	self assert: presenter model selectedText isNil.
	self assert: presenter model selectionInterval isNil! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 21:16'!
testTextPortWithDifferentSelectionsInitialization
	presentation entity: 'A test text'.
	presentation selectedText: 'test'.
	presentation selectionInterval: (-1 to: 3).
	self establishSession.
	
	self assert: presentation text = 'A test text'.
	self assert: presentation selectedText = 'A t'.
	self assert: presentation selectionInterval = (-1 to: 3).
	
	self assert: presenter model text = 'A test text'.
	self assert: presenter model selectedText = 'A t'.
	self assert: presenter model selectionInterval = (-1 to: 3)! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 22:48'!
testTextPortWithSelectedTextInitialization
	presentation entity: 'A test text'.
	presentation selectedText: 'text'.
	self establishSession.
	
	self assert: presentation text = 'A test text'.
	self assert: presentation selectedText = 'text'.
	self assert: presentation selectionInterval = (8 to: 11).
	
	self assert: presenter model text = 'A test text'.
	self assert: presenter model selectedText = 'text'.
	self assert: presenter model selectionInterval = (8 to: 11)! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 20:58'!
testTextPortWithSelectionInitialization
	presentation entity: 'A test text'.
	presentation selectedText: 'test text'.
	presentation selectionInterval: (3 to: 11).
	self establishSession.
	
	self assert: presentation text = 'A test text'.
	self assert: presentation selectedText = 'test text'.
	self assert: presentation selectionInterval = (3 to: 11).
	
	self assert: presenter model text = 'A test text'.
	self assert: presenter model selectedText = 'test text'.
	self assert: presenter model selectionInterval = (3 to: 11)! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 20:57'!
testTextPortWithSelectionIntervalInitialization
	presentation entity: 'A test text'.
	presentation selectionInterval: (1 to: 1).
	self establishSession.
	
	self assert: presentation text = 'A test text'.
	self assert: presentation selectionInterval = (1 to: 1).
	self assert: presentation selectedText = 'A'.
	
	self assert: presenter model text = 'A test text'.
	self assert: presenter model selectionInterval = (1 to: 1).
	self assert: presenter model selectedText = 'A'.! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 20:52'!
testTextPortWithoutSelectionInitialization
	presentation entity: 'A test text'.
	self establishSession.
	
	self assert: presentation text = 'A test text'.
	self assert: presenter model text = 'A test text'.
	self assert: presenter model selectedText isNil.
	self assert: presenter model selectionInterval isNil! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/6/2010 01:45'!
testTextWithSelectedTextAnnouncements
	self establishSession.
	presentation text: 'Some text to test'.
	presentation selectedText: 'text'.

	self assert: presenter model text = 'Some text to test'.
	self assert: presenter model selectedText = 'text'.
	self assert: presenter model selectionInterval = (6 to: 9).
	self assert: presentation selectionInterval = (6 to: 9).
	
	presentation selectedText: 'not found'.
	self assert: presenter model selectedText = 'not found'.
	self assert: presenter model selectionInterval = nil.
	! !

!SGLTextPresenterTest methodsFor: 'testing' stamp: 'AndreiChis 9/5/2010 20:34'!
testTextWithSelectionIntervalAnnouncements
	self establishSession.
	presentation text: 'Some text to test'.
	presentation selectionInterval: '2 to: 5'.

	self assert: presenter model text = 'Some text to test'.
	self assert: presenter model selectionInterval = (2 to: 5).
	self assert: presenter model selectedText = 'ome t'.
	
	presentation selectionInterval: (100 to: 101).
	self assert: presenter model selectionInterval = (100 to: 101).
	self assert: presenter model selectedText = nil.
	! !
